[gimp] app, desktop: fix the Alt-click exclusive visibility case.



commit 05d226c34312c9dd6ecb010188adf3f4605a43a5
Author: Jehan <jehan girinstud io>
Date:   Tue Feb 15 21:28:10 2022 +0100

    app, desktop: fix the Alt-click exclusive visibility case.
    
    We want it to work whatever the level in the item tree. We only care
    about whether the items are selected or not.
    
    Also fixing the AppStream release tag for the description of this
    feature.

 app/core/gimpitem-exclusive.c           | 8 +++++---
 desktop/org.gimp.GIMP.appdata.xml.in.in | 2 +-
 2 files changed, 6 insertions(+), 4 deletions(-)
---
diff --git a/desktop/org.gimp.GIMP.appdata.xml.in.in b/desktop/org.gimp.GIMP.appdata.xml.in.in
index 89f3b641ee..e7d41cc43e 100644
--- a/desktop/org.gimp.GIMP.appdata.xml.in.in
+++ b/desktop/org.gimp.GIMP.appdata.xml.in.in
@@ -87,7 +87,7 @@
           Lock icons in item dockables (Layers, Channels, Paths) moved next to the visibility (eye) icon
           </_li>
           <_li>
-          Alt-click on visibility and lock icons in item dockables massively toggles on same level
+          Alt-click on visibility and lock icons in item dockables massively toggles visibility and locks 
among selected items
           </_li>
           <_li>
           New checkbox to enable or disable dynamics in paint tools' options (replacing "Dynamics Off" 
dynamics)


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/app/core/gimpitem-exclusive.c b/app/core/gimpitem-exclusive.c
index 301f2d9074..6eadc31f81 100644
--- a/app/core/gimpitem-exclusive.c
+++ b/app/core/gimpitem-exclusive.c
@@ -215,9 +215,11 @@ gimp_item_exclusive_get_lists (GimpItem              *item,
           /* Do we care only about selected drawables? */
           (! only_selected  || gimp_image_is_selected_drawable (image,
                                                                 GIMP_DRAWABLE (other))) &&
-          /* We are only interested in same level items. */
-          gimp_viewable_get_parent (GIMP_VIEWABLE (other)) ==
-          gimp_viewable_get_parent (GIMP_VIEWABLE (item)))
+          /* We are only interested in same level items unless
+           * @only_selected is TRUE. */
+          (only_selected ||
+           gimp_viewable_get_parent (GIMP_VIEWABLE (other)) ==
+           gimp_viewable_get_parent (GIMP_VIEWABLE (item))))
         {
           if (is_enabled (other))
             *on = g_list_prepend (*on, other);